jactorch.data.dataset
=====================

.. automodule:: jactorch.data.dataset

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      Dataset
      FilterableDatasetUnwrapped
      FilterableDatasetView
      IterableDatasetMixin
      JacDataset
      ListDataset
      ProxyDataset
   
   

   
   
   

   
   
   








.. rubric:: Class Dataset
.. autoclass:: Dataset
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class FilterableDatasetUnwrapped
.. autoclass:: FilterableDatasetUnwrapped
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class FilterableDatasetView
.. autoclass:: FilterableDatasetView
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class IterableDatasetMixin
.. autoclass:: IterableDatasetMixin
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class JacDataset
.. autoclass:: JacDataset
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class ListDataset
.. autoclass:: ListDataset
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class ProxyDataset
.. autoclass:: ProxyDataset
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







